@@ -70,6 +70,20 @@ enum PropResult {
     , PROP_TODO = 3
 };
 
+struct Trail {
+
+    Trail () {
+    }
+
+    Trail (Lit _lit, uint32_t _lev) :
+        lit(_lit)
+        , lev(_lev)
+    {}
+
+    Lit lit;
+    uint32_t lev;
+};
+
 /**
 @brief The propagating and conflict generation class
 
@@ -98,15 +112,36 @@ public:
         return trail.size();
     }
     Lit trail_at(size_t at) const {
-        return trail[at];
+        return trail[at].lit;
     }
     bool propagate_occur();
     PropStats propStats;
     template<bool update_bogoprops = true>
-    void enqueue(const Lit p, const PropBy from = PropBy());
+    void enqueue(const Lit p, const uint32_t level, const PropBy from = PropBy());
+    template<bool update_bogoprops = true>
+    void enqueue(const Lit p);
     void new_decision_level();
     vector<double> var_act_vsids;
     vector<double> var_act_maple;
+    vector<double> lit_act_lsids;
+
+    //Variable activities
+    struct VarOrderLt { ///Order variables according to their activities
+        const vector<double>&  activities;
+        bool operator () (const uint32_t x, const uint32_t y) const
+        {
+            return activities[x] > activities[y];
+        }
+
+        explicit VarOrderLt(const vector<double>& _activities) :
+            activities(_activities)
+        {}
+    };
+
+    ///activity-ordered heap of decision variables.
+    ///NOT VALID WHILE SIMPLIFYING
+    Heap<VarOrderLt> order_heap_vsids;
+    Heap<VarOrderLt> order_heap_maple;
 
 protected:
     int64_t simpDB_props = 0;
@@ -124,29 +159,11 @@ protected:
 
     // Solver state:
     //
-    vector<Lit>         trail;            ///< Assignment stack; stores all assigments made in the order they were made.
+    vector<Trail>         trail;            ///< Assignment stack; stores all assignments made in the order they were made.
     vector<uint32_t>    trail_lim;        ///< Separator indices for different decision levels in 'trail'.
     uint32_t            qhead;            ///< Head of queue (as index into the trail)
     Lit                 failBinLit;       ///< Used to store which watches[lit] we were looking through when conflict occured
 
-
-    struct VarOrderLt { ///Order variables according to their activities
-        const vector<double>&  activities;
-        bool operator () (const uint32_t x, const uint32_t y) const
-        {
-            return activities[x] > activities[y];
-        }
-
-        explicit VarOrderLt(const vector<double>& _activities) :
-            activities(_activities)
-        {}
-    };
-
-    ///activity-ordered heap of decision variables.
-    ///NOT VALID WHILE SIMPLIFYING
-    Heap<VarOrderLt> order_heap_vsids;
-    Heap<VarOrderLt> order_heap_maple;
-
     friend class EGaussian;
 
     template<bool update_bogoprops>
@@ -243,6 +260,7 @@ private:
         const Watched* i
         , const Lit p
         , PropBy& confl
+        , uint32_t currLevel
     ); ///<Propagate 2-long clause
     template<bool update_bogoprops>
     bool prop_long_cl_any_order(
@@ -250,6 +268,7 @@ private:
         , Watched*& j
         , const Lit p
         , PropBy& confl
+        , uint32_t currLevel
     );
 };
 
@@ -361,6 +380,7 @@ inline PropResult PropEngine::handle_normal_prop_fail(
     confl = PropBy(offset);
     #ifdef VERBOSE_DEBUG_FULLPROP
     cout << "Conflict from ";
+    Clause& c = *cl_alloc.ptr(offset);
     for(size_t i = 0; i < c.size(); i++) {
         cout  << c[i] << " , ";
     }
@@ -382,7 +402,13 @@ inline PropResult PropEngine::handle_normal_prop_fail(
 }
 
 template<bool update_bogoprops>
-void PropEngine::enqueue(const Lit p, const PropBy from)
+void PropEngine::enqueue(const Lit p)
+{
+    enqueue<update_bogoprops>(p, decisionLevel(), PropBy());
+}
+
+template<bool update_bogoprops>
+void PropEngine::enqueue(const Lit p, const uint32_t level, const PropBy from)
 {
     #ifdef DEBUG_ENQUEUE_LEVEL0
     #ifndef VERBOSE_DEBUG
@@ -413,7 +439,7 @@ void PropEngine::enqueue(const Lit p, const PropBy from)
         assert(sumConflicts >= varData[v].cancelled);
         uint32_t age = sumConflicts - varData[v].cancelled;
         if (age > 0) {
-            double decay = std::pow(0.95, age);
+            double decay = std::pow(maple_decay_base, age);
             var_act_maple[v] *= decay;
             if (order_heap_maple.inHeap(v))
                 order_heap_maple.increase(v);
@@ -423,7 +449,7 @@ void PropEngine::enqueue(const Lit p, const PropBy from)
     const bool sign = p.sign();
     assigns[v] = boolToLBool(!sign);
     varData[v].reason = from;
-    varData[v].level = decisionLevel();
+    varData[v].level = level;
     if (!update_bogoprops) {
         varData[v].polarity = !sign;
         #ifdef STATS_NEEDED
@@ -434,7 +460,7 @@ void PropEngine::enqueue(const Lit p, const PropBy from)
         }
         #endif
     }
-    trail.push_back(p);
+    trail.push_back(Trail(p, level));
 
     if (update_bogoprops) {
         propStats.bogoProps += 1;
