@@ -36,9 +36,9 @@ struct SolveFeatures
     //Some parameter
     double eps = 0.00001;
 
-    int numVars;
-    int numClauses;
-    double var_cl_ratio;
+    int numVars = 0;
+    int numClauses = 0;
+    double var_cl_ratio = 0;
 
     //Clause distribution
     double binary = 0;
@@ -47,31 +47,31 @@ struct SolveFeatures
     double horn_std = 0;
     double horn_min = std::numeric_limits<double>::max();
     double horn_max = std::numeric_limits<double>::min();
-    double horn_spread;
+    double horn_spread = 0;
 
     double vcg_var_mean = 0;
     double vcg_var_std = 0;
     double vcg_var_min = std::numeric_limits<double>::max();
     double vcg_var_max = std::numeric_limits<double>::min();
-    double vcg_var_spread;
+    double vcg_var_spread = 0;
 
     double vcg_cls_mean = 0;
     double vcg_cls_std = 0;
     double vcg_cls_min = std::numeric_limits<double>::max();
     double vcg_cls_max = std::numeric_limits<double>::min();
-    double vcg_cls_spread;
+    double vcg_cls_spread = 0;
 
     double pnr_var_mean = 0;
     double pnr_var_std = 0;
     double pnr_var_min = std::numeric_limits<double>::max();
     double pnr_var_max = std::numeric_limits<double>::min();
-    double pnr_var_spread;
+    double pnr_var_spread = 0;
 
     double pnr_cls_mean = 0;
     double pnr_cls_std = 0;
     double pnr_cls_min = std::numeric_limits<double>::max();
     double pnr_cls_max = std::numeric_limits<double>::min();
-    double pnr_cls_spread;
+    double pnr_cls_spread = 0;
 
     //Conflict clauses
     double avg_confl_size = 0.0;
@@ -112,8 +112,8 @@ struct SolveFeatures
     Distrib red_cl_distrib;
 
     //High-level features
-    uint64_t num_gates_found_last;
-    uint64_t num_xors_found_last;
+    uint64_t num_gates_found_last = 0;
+    uint64_t num_xors_found_last = 0;
 };
 
 }
