@@ -70,7 +70,8 @@ class InTree;
 
 struct SolveStats
 {
-    uint64_t numSimplify = 0;
+    uint32_t num_simplify = 0;
+    uint32_t num_simplify_this_solve_call = 0;
     uint32_t num_solve_calls = 0;
 };
 
@@ -138,6 +139,10 @@ class Solver : public Searcher
         void add_in_partial_solving_stats();
         void check_implicit_stats(const bool onlypairs = false) const;
         void check_stats(const bool allowFreed = false) const;
+        void enable_comphandler();
+        bool implied_by(const std::vector<Lit>& lits,
+            std::vector<Lit>& out_implied
+        );
 
 
         //Checks
@@ -262,6 +267,8 @@ class Solver : public Searcher
         //Helper
         void renumber_xors_to_outside(const vector<Xor>& xors, vector<Xor>& xors_ret);
         void testing_set_solver_not_fresh();
+        void check_assigns_for_assumptions() const;
+        bool check_assumptions_contradict_foced_assignment() const;
 
     private:
         friend class Prober;
@@ -270,6 +277,7 @@ class Solver : public Searcher
         FRIEND_TEST(SearcherTest, pickpolar_auto_not_changed_by_simp);
         #endif
 
+        vector<Lit> implied_by_tmp_lits;
         vector<Lit> add_clause_int_tmp_cl;
         lbool iterate_until_solved();
         uint64_t mem_used_vardata() const;
@@ -322,7 +330,7 @@ class Solver : public Searcher
         void print_full_restart_stat(const double cpu_time, const double cpu_time_total) const;
 
         lbool simplify_problem(const bool startup);
-        bool execute_inprocess_strategy(const bool startup, const string& strategy);
+        lbool execute_inprocess_strategy(const bool startup, const string& strategy);
         SolveStats solveStats;
         void check_minimization_effectiveness(lbool status);
         void check_recursive_minimization_effectiveness(const lbool status);
